<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Ajax extends CI_Controller
{

    public function __construct()
    {        
        parent::__construct();
        $this->load->model('searchmodel');
        $this->load->model('statusmodel');
        $this->load->model('settingsmodel');
        $this->load->model('productsmodel');
        $this->load->model('cartmodel');
        $this->load->model('favoritosmodelo');
        $this->load->library('cart');
        $this->statusmodel->checkUser();

    }

    public function consulta()
    {
        $response           = new stdClass();
        $response->success  = false;
        $response->text     = 'No inicializado';

        $this->form_validation->set_rules('nombre', 'Nombre completo', 'trim|'.($this->statusmodel->checkUser() ? '' : 'required').'');
        $this->form_validation->set_rules('email', 'E-mail', 'trim|'.($this->statusmodel->checkUser() ? '' : 'required|').'valid_email');
        $this->form_validation->set_rules('consulta', 'Consulta', 'trim|required');
        $this->form_validation->set_rules('id', 'Producto', 'trim|required');

        if( $this->form_validation->run() )
        {
            $nombre         = false;
            $email          = false;
            $consulta       = html_escape( $this->input->post('consulta', true) );
            $producto_id    = intval( $this->input->post('id') );

            $producto       = $this->productsmodel->single( $producto_id );

            if( $this->statusmodel->checkUser() )
            {
                $user = $this->statusmodel->getLoggedUser();

                $nombre     = $user->name . ' ' . $user->lastname;
                $email      = $user->mail;
            }
            else
            {
                $nombre     = html_escape( $this->input->post('nombre', true) );
                $email      = html_escape( $this->input->post('email', true) );
            }

            $email_html = array(

                'nombre'    => $nombre,
                'email'     => $email,
                'consulta'  => $consulta,
                'producto'  => $producto,

            );

            $html = $this->load->view('emails/consulta-single', $email_html, true );

            $data = array(

                'titulo'    => 'Consulta por ' . $producto->name,
                'html'      => $html,
                'footer'    => false,
            );

            $render = $this->load->view('email', $data, true);

            $config = array(

                'to'        => $this->config->item('email_to'),
                'bcc'       => $this->config->item('email_to_bcc'),
                'reply_to'  => $email,
                'subject'   => 'Consulta vía web ' . $producto->name,
                'html'      => $render,

            );

            if( $this->functions->sendEmail($config) )
            {
                $response->success = true;
                $response->text = 'Su consulta ha sido enviada correctamente, nos pondremos en contacto con usted a la brevedad.';   
            }
            else
            {
                $response->text = 'No se ha podido enviar la consulta';
            }

        }
        else
        {
            $response->text = validation_errors();
        }


        echo json_encode($response);
    }

    public function register_user()
    {
        $this->load->model('usersmodel');

        $data['success']    = false;
        $data['msg']        = "";

    
        $error = false;

        if( $this->form_validation->run('register') )
        {
            $this->load->helper('string');
            
            $token = random_string('md5', 32);

            $user = array(

                'id'            => null,
                'name'          => html_escape( $this->input->post('name', true) ),
                'lastname'      => html_escape($this->input->post('lastname', true) ),
                'mail'          => html_escape($this->input->post('mail', true) ),
                'pass'          => md5(html_escape($this->input->post('password', true) ) ),
                'register_time' => date('Y-m-d H:i:s'),
                'token'         => $token,
                'token_date'    => time(),
                
            );

            if( $this->usersmodel->add_tmp($user) )
            {
                $id = $this->usersmodel->last_tmp();
                
                $texto  = '<p>Muchas gracias por registrarse en ' . $this->config->item('site_name') . '</p>';
                $texto .= '<p>Para completar el registro, por favor haz click en el siguiente enlace</p>';
                $texto .= '<p><a href="'.base_url().'registro/'. $token . '/'. $id .'">'.base_url().'registro/'. $token . '/'. $id .'</a></p>';
                $texto .= '<p>¡Muchas gracias!</p>';


                $mail = array(

                    'titulo'        => '',
                    'html'          => $texto,
                    'footer'        => true,

                );

                $html = $this->load->view('email', $mail, true);

                $datos_email = array(

                    'to'        => $this->input->post('mail', true),
                    'reply_to'  => $this->config->item('smtp_user'),
                    'subject'   => 'Bienvenido a ' . $this->config->item('site_name'),
                    'html'      => $html
                
                );

                $this->functions->sendEmail( $datos_email );

                $data['success']    = true;
                $data['msg']        = '<h2 class="text-center">¡Bienvendido!</h2><p class="text-center">Comprueba tu e-mail para completar el registro.</p>';
            }
            else
            {
                $data['success'] = false;
                $data['msg'] = "Se ha producido un error!";
            }
            
        }
        else
        {
            $data['success'] = false;
            $data['msg'] = validation_errors('<p class="text-danger" style="margin-bottom:0px">', '</p>');
        }


        echo json_encode($data);
    }

    public function access($msj = false)
    {
        $this->load->model('statusmodel');
        $data['msg']        = false;
        $data['success']    = false;

        if( isset($_POST['user']) )
        {
            $user = html_escape( $this->input->post('user', true) );
            $pass = html_escape( $this->input->post('password', true) );

            if( $this->form_validation->run('access') )
            {

                $user_object = $this->statusmodel->getUser($user, $pass);

                if( $user_object != false )
                {
                    
                    $this->statusmodel->setUserSession($user_object, $this->input->post('recordar') );
                    
                    $data['msg']        = false;
                    $data['success']    = true;
                    
                }
                else
                {
                    $data['msg']    = '<p class="text-danger">Datos Incorrectos</p>';
                }
                
            }
            else
            {
                $data['msg'] = '<p class="text-danger">Formulario no válido.</p>';
            }
            
        }

        echo json_encode($data);
    }

    public function buscar()
    {
        $key = html_escape( $this->input->post('termino', true) );

        $productos = $this->productsmodel->buscar($key);

        $html = '';

        if($productos)
        {   
            $html .= '<p style="margin-left:15px;color:white">Resultados para la busqueda : "'.$key.'"</p>';
            foreach($productos as $key => $producto)
            {
                $html .= $this->render->sidebarProduct($producto);
            }
        }

        echo $html;
    }

    public function favoritos()
    {

        $obj = new stdClass();
        $obj->error = true;

        if( $this->statusmodel->checkUser() )
        {
            
            $producto       = $this->security->xss_clean($this->input->post('producto'));
            $usuario        = $this->statusmodel->getLoggedUser();
            
            $estado         = $this->favoritosmodelo->checkFavorito($producto, $usuario->id);

            if(!$estado)
            {
                $this->favoritosmodelo->agregarFavorito($producto, $usuario->id);
                $obj->estado = 'activo';
                $obj->error = false;
            }
            else
            {
                $this->favoritosmodelo->quitarFavorito($producto, $usuario->id);
                $obj->estado = 'inactivo';
                $obj->error = false;
            }

        }
        else
        {
            $obj->estado = 'not_logged';
        }

        echo json_encode($obj);
    }

    public function modal_producto()
    {

        $json = new stdClass();
        $json->success = true;

        if( isset($_POST['id']) )
        {
            $producto = $this->productsmodel->single($this->input->post('id'));

            $json->text =   '<div class="modal fade" id="modal-producto">
                                <div class="modal-dialog" style="position: relative;top: 150px;">
                                    <div class="modal-content">

                                        <div class="modal-header">
                                            <button type="button" class="close" data-dismiss="modal"><span aria-hidden="true">&times;</span><span class="sr-only">Close</span></button>
                                            <h4 class="modal-title">Producto agregado al carrito!</h4>
                                        </div>

                                        <div class="modal-body">
                                            <div class="row">

                                                <div class="col-xs-5">

                                                    <img src="'.$producto->thumb.'" class="thumbnail img-responsive" width="100%" />

                                                </div>

                                                <div class="col-xs-7">

                                                    <h4>'.$producto->name.'</h4>
                                                    <p>Precio : '. $this->functions->precio($producto->cart) .'</p>

                                                </div>

                                            </div>
                                            
                                        </div>

                                        <div class="modal-footer">
                                            <a href="productos/'.$producto->category_slug.'" class="btn btn-default">Otros Productos</button>
                                            <a href="carrito" class="btn btn-primary">Finalizar Pedido</a>
                                        </div>
                                    </div>
                                </div>
                            </div>';
        }
        else
        {
            show_404();
        }
        
        echo json_encode($json);
    }

    public function get_carrito_header()
    {   
        $mostrar = $this->input->post('mostrar', true) == 'true' ? true : false;

        echo $this->render->carrito_header($mostrar);
    }

    public function actualizar_carrito()
    {
        $objeto             = new stdClass();
        $objeto->success    = false;

        $id = $this->input->post('id', true);

        if(!$id)
        {
            echo json_encode($objeto);
        }
        else
        {
            $data = array(
                
                'rowid' => $id,
                'qty'   => 0
            );

            if( $this->cart->update($data) )
            {
                $objeto->success    = true;
                $objeto->qty        = $this->cart->total_items() . ($this->cart->total_items() == 1 ? ' producto' : ' productos');
            }

            echo json_encode($objeto);
        }
    }

    public function agendar()
    {

        $response = new stdClass();
        $response->success = false;
        $response->text = '';

        if( $this->form_validation->run('agendar') )
        {

            $texto  = '<p>Nueva solicitud de reunión</p>';

            $texto .= '<p>Nombre : '.$this->input->post('nombre', true).'</p>';
            $texto .= '<p>Apellido : '.$this->input->post('apellido', true).'</p>';
            $texto .= '<p>Empresa : '.$this->input->post('empresa', true).'</p>';
            $texto .= '<p>Teléfono : '.$this->input->post('telefono', true).'</p>';
            $texto .= '<p>Dirección : '.$this->input->post('direccion', true).'</p>';
            $texto .= '<p>E-mail : '.$this->input->post('email', true).'</p>';
            $texto .= '<p>Fecha de la reunión : '.$this->input->post('fecha', true).'</p>';
            $texto .= '<p>Mensaje : '.$this->input->post('mensaje', true).'</p>';

            $mail = array(

                'titulo'        => '',
                'html'          => $texto,
                'footer'        => true,

            );

            $html = $this->load->view('email', $mail, true);

            $datos_email = array(

                'to'        => $this->config->item('email_to'),
                'reply_to'  => $this->config->item('smtp_user'),
                'subject'   => 'Nueva solicitud de reunión',
                'html'      => $html
            
            );

            if( $this->functions->sendEmail( $datos_email ) )
            {
                $response->success = true;
            }
            else
            {
                $response->text = $this->email->print_debugger(array('headers')); // 'No se ha podido enviar el mensaje';
            }

        }
        else
        {
            $response->text = validation_errors();
        }

        echo json_encode($response);

    }

 

}
