<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Products extends CI_Controller{

	private $tipo           = "productos";
    private $resultados     = 100;
    private $categoria      = false;
    private $orden          = "important DESC, active DESC, name ASC";

	public function __construct()
	{
	   	parent::__construct();

	   	$this->load->model('settingsmodel');
	   	$this->load->model('statusmodel');
	   	$this->load->model('productsmodel');
	   	$this->load->model('imgmodel');
        $this->load->model('categoriesmodel');
        $this->load->model('searchmodel');
        $this->load->model('cartmodel');
	   	$this->load->library('image_lib');
        $this->session->set_userdata('admin_menu', 'products');

        if( ! $this->statusmodel->loggedAdmin())
        {
            redirect('admin');
            exit();
        }

        if($this->session->userdata('resultados') != false)
        {
            $this->resultados = $this->session->userdata('resultados');
        }

        if($this->session->userdata('categoria') != false)
        {
            $this->categoria = $this->session->userdata('categoria');

            if($this->categoria == '')
            {
                $this->categoria = false;
            }
        }

    }

	public function listar($inicio = 0)
	{

		$this->templates_admin->head();
		$this->templates_admin->header(array('title' => 'Lista de productos'));
        $this->templates_admin->sidebar();
        $this->templates_admin->subMenu(array('Nuevo+' => 'productos/nuevo'), true, true, 'productos');

        $config = array(

            'base_url'      => base_url('admin/productos/listar'),
            'total_rows'    => $this->productsmodel->count($this->categoria),
            'per_page'      => $this->resultados,
            'uri_segment'   => 4,
            'full_tag_open' => '<div class="paginador">',
            'full_tag_close'=> '</div>'

        );

        $this->pagination->initialize($config);

        $data = array(

            'msj'           => '',
            $this->tipo     => $this->productsmodel->get($inicio, $this->resultados, $this->orden, $this->categoria),
            'tipo'          => $this->tipo,
            'paginador'     => $this->pagination->create_links()
        );

		$this->load->view('admin/'.$this->tipo.'/list', $data);
		
		$this->templates_admin->footer();
	}



    public function nuevo()
    {
        
        $this->templates_admin->head( array('editor' => true ) );
        $this->templates_admin->header(array('title' => 'Nuevo producto'));

        $data = array( 

            'tipo'          => $this->tipo,
            'categories'    => $this->categoriesmodel->get(true),
            'added'         => false,
        );

     
        if($this->form_validation->run('products'))
        {
            // $fields         = json_encode($_POST['fields']);
            // $values         = json_encode($_POST['values']);
            // $order          = json_encode($_POST['order']);

            $array = array(

                'id'            => null,
                'name'          => $this->input->post('name'),
                'description'   => $this->input->post('description'),
                // 'fields'        => $fields,
                // 'values'        => $values,
                // 'fields_order'  => $order,
                'code'          => $this->input->post('code'),
                'category'      => $this->input->post('category'),
                'slug'          => url_title($this->input->post('name'), '-', true),
                'active'        => 0
            );

            if($this->productsmodel->add($array))
            {
                
                $this->cartmodel->add();
                
                redirect('admin/productos/imagenes/' . $this->productsmodel->last() );
            }
        }
        
        $accion = $data['added'] ? 'volver' : 'cancelar';
        $link   = $accion == 'volver' ? 'productos/listar' : '#modal-cancelar';

        $this->templates_admin->sidebar();

        $this->templates_admin->subMenu(array($accion => $link ));
        

        $this->load->view('admin/'.$this->tipo.'/nuevo', $data);
        
        $this->templates_admin->footer();
    }

    public function editar($product)
    {

        $this->templates_admin->head();
        $this->templates_admin->header(array('title' => 'Editar producto'));
        $object['product'] = $this->productsmodel->single($product);

        $data = array(

            'tipo'          => $this->tipo,
            'categories'    => $this->categoriesmodel->get(true),
            'product'       => $object['product'],
            'previa'        => $this->load->view('admin/templates/previa', $object, true)
        );

        if($this->form_validation->run('products'))
        {
            // $fields         = json_encode($_POST['fields']);
            // $values         = json_encode($_POST['values']); 
            // $order          = json_encode($_POST['order']);

            $array = array(

                'name'          => $this->input->post('name'),
                'description'   => $this->input->post('description'),
                // 'fields'        => $fields,
                // 'values'        => $values,
                // 'fields_order'  => $order,
                'category'      => $this->input->post('category'),
                'code'          => $this->input->post('code'),
                // 'brand'         => $this->input->post('brand'),
                'slug'          => url_title($this->input->post('name'), '-', true),
                'tags'          => $this->input->post('tags')
            );

            if($this->productsmodel->update($product, $array))
            {
                redirect('admin/productos/listar');
            }
        }
        
        $this->templates_admin->sidebar();

        $this->templates_admin->subMenu(array('cancelar' => 'productos/listar' ));

        $this->load->view('admin/'.$this->tipo.'/edit', $data);
        
        $this->templates_admin->footer();
    }

    public function ordenar_campos($id = false)
    {

        $this->templates_admin->head();
        $this->templates_admin->header(array('title' => 'Editar producto'));

        $data['product'] = $this->productsmodel->single($id);

        $this->templates_admin->subMenu(array('volver al producto' => 'productos/editar/'.$data['product']->id ));
        $this->load->view('admin/'.$this->tipo.'/orden', $data);

        $this->templates_admin->footer();
    }

    public function imagenes($product)
    {

        $this->templates_admin->head();
		$this->templates_admin->header(array('title' => 'Subir Fotos'));
    
        $data['url_prod']   = base_url().'admin/'.$this->tipo.'/editar/'.$product;

        $confirmar = false;
        $data['msj']    = "";

        if(isset($_POST['subir']))
        {
            if( ! empty($_FILES['fotos']['name'][0]))
            {
                if( ! file_exists($this->settingsmodel->get('pics_path').$product))
                {
                    mkdir($this->settingsmodel->get('pics_path').$product);
                }
        
                $number = $this->imgmodel->imgLastNumber($product);
                $number +=1;
                $i = 0;
                
                foreach($_FILES['fotos']['name'] as $foto)
                {
                    
                    if($_FILES['fotos']['type'][$i] != 'image/jpeg' && $_FILES['fotos']['type'][$i] != 'image/png')
                    {
                        $error = true;
                    }
                    elseif($_FILES['fotos']['error'][$i] != 0)
                    {
                        $error = true;
                    }
                    else
                    {
                        $error = false;
                    }

                    if( ! $error)
                    {
                        $ext = pathinfo($_FILES['fotos']['name'][$i], PATHINFO_EXTENSION);

                        if(move_uploaded_file($_FILES['fotos']['tmp_name'][$i], $this->settingsmodel->get('pics_path').$product.'/'.$number.'.'.$ext))
                        {
                            $config['image_library']    = 'gd2';
                            $config['source_image']     = $this->settingsmodel->get('pics_path').$product.'/'.$number.'.'.$ext;
                            $config['create_thumb']     = TRUE;
                            $config['maintain_ratio']   = FALSE;
                            $config['width']            = $this->config->item('thumb_width');
                            $config['height']           = $this->config->item('thumb_height');
                             
                            $this->image_lib->initialize($config);

                            if($this->image_lib->resize())
                            {
                                $this->image_lib->clear();   
                                //pregunto cual es el ultimo numero de orden
                                $u = $this->imgmodel->imgLastOrder($product);
                                
                                if($u != false)
                                {
                                    $i2 = $u;
                                }
                                else
                                {
                                    $i2 = $i;
                                }
                                $data_img = array(

                                    'id'        => null,
                                    'number'    => $number,
                                    'original'  => $_FILES['fotos']['name'][$i],
                                    'product'   => $product,
                                    'text'      => '',
                                    'order'     => $i2+1,
                                    'extension' => $ext,
                                    'active'    => 1
                                );

                                $this->imgmodel->add($data_img);
                            }


                        }
                        
                    }

                    $number++;
                    $i++;
                }

                redirect('admin/productos/imagenes/' . $product);
            }
            else
            {
                $data['msj'] = 'Debe subir por lo menos una imagen (.jpg/.png)';
            }
        }
        elseif(isset($_POST['items']))
        {
            if($_POST['items'] != '')
            {
                $items = '';
                foreach($_POST as $key => $value)
                {

                    if($_POST['items'] == 'eliminar')
                    {
                        $array = explode('_', $key);
                        $array = $array[0];
                        if($key != 'items' && $array != 'foto'){

                            $items .= $key.', ';
                        }

                    }
                    //si le doy activar
                    elseif($_POST['items'] == 'activar')
                    {
                        $array = explode('_', $key);
                        $array = $array[0];
                        if($key != 'items' && $array != 'foto')
                        {
                            $this->imgmodel->setActive($key, true);
                            $data['accion'] = 'Activacion';
                        }
                    }
                    //si le doy desactivar
                    elseif($_POST['items'] == 'desactivar')
                    {
                        $array = explode('_', $key);
                        $array = $array[0];
                        if($key != 'items' && $array != 'foto')
                        {
                            $this->imgmodel->setActive($key, false);
                            $data['accion'] = 'Desactivacion';
                        }
                    }
                }

                //si la accion fue eliminar
                if($_POST['items'] == 'eliminar')
                {
                   // var_dump($_POST);
                    $items              = substr($items,0, -2);
                    $cantidad           = explode(', ', $items);
                    $cantidad           = count($cantidad);
                    $data['items']      = $items;
                    $data['cantidad']   = $cantidad;
                    $data['tipo1']      = 'centros';
                    $data['tipo']       = 'masivo';

                    //si hay solo 1 item, no pido confirmacion, elimino.
                    if($cantidad == 1)
                    {
                        if($this->imgmodel->delete($items))
                        {
                            $data['msj'] = "Eliminacion realizada con exito";
                        }
                        else
                        {
                            $data['msj'] = "Se ha producido un error al eliminar";
                        }
                    }
                    //si hay varios items, pido confirmacion.
                    else
                    {
                        $confirmar = true;
                    }
                }
                else
                {        
                    $data['items']  = 'centros';
                    $data['msj']    = $data['accion'].' exitosa';
                }

            }
            else
            {
                foreach ($_POST as $id => $value)
                {         
                    if($id != 'items' && $id != 'actualizar' && $value != 'on' && $value != 'off')
                    {
                        $array  = explode('_', $id);
                        $id     = $array[1];
                        $this->imgmodel->edit($id, $value);
                    }
                }
            }
        }
        elseif(isset($_POST['confirmar']))
        {
            foreach($_POST as $key => $value)
            {
                if($key != 'confirmar')
                {
                    $this->imgmodel->delete($value);
                }
            }
            
            $data['tipo'] = 'masivo';
            $data['msj'] = "Eliminacion realizada con exito";
        }
        
        $data['uploaded'] = $this->imgmodel->get($product, false);
        
        $object['product']  = $this->productsmodel->single($product);
        $data['previa']   = $this->load->view('admin/templates/previa', $object, true);

        $this->templates_admin->sidebar();

        $this->templates_admin->subMenu(array('volver' => 'productos/listar', 'volver a edicion' => 'productos/editar/' . $product, 'siguiente' => 'productos/carrito/' . $product), false, true, 'imagenes');

        if( ! $confirmar)
        {
            $this->load->view('admin/pics/edit', $data);
        }
        else
        {
            $this->load->view('admin/confirmar', $data);     
        }
        
    
        $this->templates_admin->footer();
    }

    public function buscar()
    {
        if( ! isset($_POST['keyword']))
        {
            redirect('admin/productos/listar');
        }

        $this->templates_admin->head();
        $this->templates_admin->header(array('title' => 'Resultados para la busqueda'));
        $this->templates_admin->sidebar();
        $this->templates_admin->subMenu(array('cerrar' => 'productos/listar' ), false, true, 'productos');

        $results    = $this->searchmodel->get($this->input->post('keyword', true));
        

        $suffix = "s";
        if( ! $results)
        {
            $amount = 0;
        }
        else
        {
            $amount = count($results);
        }

        if($amount == 1)
        {
            $suffix = "";
        }

        $t = $amount.' producto'.$suffix.' encontrados';

        $data = array(

            'msj'           => $t,
            $this->tipo     => $results,
            'tipo'          => $this->tipo,
            'paginador'     => false

            );

        $this->load->view('admin/'.$this->tipo.'/list', $data);
        
        $this->templates_admin->footer();
    }

    public function carrito($product)
    {


        $object['product'] = $this->productsmodel->single($product);

        //var_dump($object['product']);

        if(!$object['product']) show_404();

        if( isset( $_POST['enviar'] ) )
        {
            $data = array(

                'product'           => $product,
                'price'             => $this->input->post('price'),
                'discount'          => $this->input->post('discount'),
                'currency'          => $this->input->post('currency'),
                'stock'             => $this->input->post('stock') == 'on' ? 1 : 0,
                'active'            => $this->input->post('active') == 'on' ? 1 : 0

            );

            if( $this->cartmodel->update($object['product']->cart->id, $data) )
            {
                redirect('admin/productos/listar');
            }
        }

        $this->templates_admin->head();
        $this->templates_admin->header(array('title' => 'Editar propiedades de venta'));

        $this->templates_admin->sidebar();

        $this->templates_admin->subMenu(array('cancelar' => 'productos/listar', 'volver a edicion' => 'productos/editar/' . $product) );

  
        $data['product']        = $this->productsmodel->single($product);


        $this->load->view('admin/'.$this->tipo.'/cart', $data);

        $this->templates_admin->footer();
    }


    public function eliminar_variante($variante_id)
    {
        $this->cartmodel->delete($variante_id);

        redirect($this->input->server('HTTP_REFERER'));
    }

    public function actualizar()
    {
        set_time_limit(1000);

        $data['mensaje'] = '';

        if(isset($_POST["enviar"]))
        {
        
            $archivo = $_FILES['csv']['name'];

            $extension = pathinfo($_FILES['csv']['name']);

            if( ! file_exists('./csv') )
            {
                mkdir('./csv', 0644);
            }
            
            if(empty($_FILES['csv']['name']))
            {
                $insertar = false;
                $mensaje = "No ha seleccionado ningun archivo CSV";
            }

            elseif($extension['extension'] != "csv")
            {
                $insertar = false;
                $mensaje = "El archivo no es un CSV";
            }
            elseif(!is_uploaded_file($_FILES['csv']['tmp_name']))
            {
                $mensaje = "Error. No se pudo subir el archivo";
                $insertar = false;
            }
            elseif(move_uploaded_file($_FILES['csv']['tmp_name'], "./csv/".$archivo) == false)
            {
                $mensaje = "El archivo no se subio correctamente";
            }  
            else
            {

                if (($gestor = fopen("csv/".$archivo, "r")) !== FALSE)
                {   
                  
                    $i = 0;
                    $n = 0;
                    $x = 0;

                    while (($datos = fgetcsv($gestor, 1000, ";")) !== FALSE)
                    {
                        if($datos[1] == '') break;

                        if($x == 0)
                        {
                            $x++;
                            continue;
                        }

                        $producto = $this->productsmodel->singleCode($datos[1]);

                        $categoria = $this->categoriesmodel->single_slug( url_title($datos[3], '-', true ) );

                        if($producto != false)
                        {
                            
                            $this->cartmodel->update($producto->id, array('price' => $datos[9]) );

                            if($categoria)
                            {
                                $this->productsmodel->update( $producto->id, array('category' => $categoria->id ) );
                            }

                            $i++;
                        }
                        else
                        {
                            $array = array(
                                
                                'id'            => null,
                                'name'          => '',
                                'code'          => $datos[1],
                                'slug'          => utf8_encode($datos[1]),
                                'active'        => 1

                            );  

                            $this->productsmodel->add($array);
                            $this->cartmodel->add();
                            $this->cartmodel->update($this->cartmodel->last(), array( 'price' => (int) $datos[9] ) );

                            if($categoria)
                            {
                                $this->productsmodel->update( $this->cartmodel->last_product(), array('category' => $categoria->id ) );
                            } 

                            $n++;
                        }

                        $x++;                        
                        
                    }
                
                    $mensaje = 'Base de datos actualizada : '. $i . ' productos actualizados - '. $n . ' productos ingresados';
                    fclose($gestor);
                    unlink("./csv/".$archivo);
                }
                
            }

            $data['mensaje'] = $mensaje;
        }

        $this->templates_admin->head();
        $this->templates_admin->header(array('title' => ''));
        $this->templates_admin->sidebar();

        $this->templates_admin->subMenu(array('Volver' => 'productos/listar' ));

        $this->load->view('admin/productos/actualizar', $data);

        $this->templates_admin->footer();
    }


}